@@ -1,6 +1,5 @@
-package relex.algs;
 /*
- * Copyright 2008 Novamente LLC
+ * Copyright 2008,2009 Novamente LLC
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,6 +14,8 @@ package relex.algs;
  * limitations under the License.
  */
 
+package relex.algs;
+
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.Map;
@@ -32,11 +33,9 @@ public class TemplateActionAlg extends TemplateMatchingAlg {
 	 */
 	private ArrayList<FeatureAction> featureActions;
 
-	protected void applyTo(FeatureNode node, RelexContext context) {
-		Map<String, FeatureNode> vars = getTemplate().match(node); 
-		if (vars == null)
-			return;
-		
+	protected void applyTo(FeatureNode node, RelexContext context,
+	                       Map<String,FeatureNode> vars)
+	{
 		Iterator<FeatureAction> i = featureActions.iterator();
 		while (i.hasNext()) {
 			FeatureAction act = i.next();
