@@ -24,7 +24,7 @@ public class DocSplitterFactory
 		{
 			Class.forName("opennlp.tools.lang.english.SentenceDetector");
 			// clazz0 = DocSplitterOpenNLPImpl.class;
-			Class<?> c = Class.forName("DocSplitterOpenNLPImpl");
+			Class<?> c = Class.forName("relex.corpus.DocSplitterOpenNLPImpl");
 
 			// It seems to be impossible to perform this cast and not get
 			// a type-safety warning,
@@ -34,7 +34,7 @@ public class DocSplitterFactory
 		{
 			System.err.println(
 				"\nWARNING:\n" +
-				"\tIt appears the the OpenNLP tools are not installed or are not\n" +
+				"\tIt appears that the OpenNLP tools are not installed or are not\n" +
 				"\tcorrectly specified in the java classpath. The OpenNLP tools are\n" +
 				"\tused to perform sentence detection. Without them, ReleEx must be\n" +
 				"\tgven one sentence per line. Please see the README file for info.\n");
